<template>
  <span>

    <el-upload
      v-if="formItem"
      ref="upload"
      :disabled="vloading"
      style="display:inline"
      :show-file-list="true"
      :before-upload="beforeUpload"
      :auto-upload="true"
      :headers="header"
      :on-success="handleSuccess"
      :on-error="handleError"
      :on-change="handleOnChange"
      :on-remove="handleOnremove"
      :action="action+'?name=' + encodeURI(form.name) + upladUrlParam"
    >

      <i v-if="vloading" class="el-icon-loading" title="文件上传中..." />
      <i v-else-if="value" class="el-icon-edit-outline" :title="placeholder" />
      <i v-else class="el-icon-plus" :loading="true" :title="placeholder" />

    </el-upload>

    <el-button
      v-if="!formItem"
      style="display:inline"

      :loading="vloading"
      :icon="btnIcon"
      @click="toUpload"
    >{{ btnLabel }}
      <el-dialog append-to-body :close-on-click-modal="false" :visible.sync="winStatus" :title="winTitle" width="520px">
        <el-form ref="form" :model="form" size="small" label-width="80px" :loading="loading">
          <el-form-item label="文件名">
            <el-input v-model="form.name" style="width: 370px;" />
          </el-form-item>
          <!--   上传文件   -->
          <el-form-item label="上传">
            <el-upload
              ref="upload"
              :limit="1"
              :before-upload="beforeUpload"
              :auto-upload="false"
              :headers="header"
              :on-success="handleSuccess"
              :on-error="handleError"
              :on-change="handleOnChange"
              :on-remove="handleOnremove"
              :action="action+'?name=' + encodeURI(form.name) + upladUrlParam"
            >
              <div class="eladmin-upload"><i class="el-icon-upload" /> 添加文件</div>
              <div v-if="fileTemplate!==null" slot="tip" class="el-upload__tip">仅上传模板格式文件，且不超过{{ fileMaxSize }}M
                <br>
                模板下载:
                <template v-if="(fileTemplate instanceof Array)">
                  <div v-for="(item,index) in fileTemplate" :key="index">
                    <a
                      :href="baseApi + '/file/'+item"
                      class="el-link--primary"
                      style="word-break:keep-all;white-space:nowrap;overflow:hidden;text-overflow:ellipsis;color: #1890ff;font-size: 13px;"
                      target="_blank"
                    >
                      {{ item }}
                    </a>
                  </div>
                </template>
                <a
                  v-else
                  :href="baseApi + '/file/'+fileTemplate"
                  class="el-link--primary"
                  style="word-break:keep-all;white-space:nowrap;overflow:hidden;text-overflow:ellipsis;color: #1890ff;font-size: 13px;"
                  target="_blank"
                >
                  {{ fileTemplate }}
                </a>
              </div>
              <div v-else slot="tip" class="el-upload__tip"> 可上传任意格式文件，且不超过{{ fileMaxSize }}M </div>
            </el-upload>
          </el-form-item>
        </el-form>
        <div slot="footer" class="dialog-footer">
          <el-button type="text" @click="cancelCU">取消</el-button>
          <el-button :loading="loading" type="primary" @click="upload">确认</el-button>
        </div>
      </el-dialog>
    </el-button>
  </span>
</template>

<script>

import qs from 'qs'
import { mapState } from 'vuex'
import CommonApi from '@/views/Manage/CommonApi.js'

export default {
  name: 'UploadFile',
  props: {
    value: {
      type: [String, Number, Object],
      default: null
    },
    formItem: {
      type: Boolean,
      default: false
    },
    placeholder: {
      type: String,
      default: '点击上传'
    },
    handleClass: {
      type: String,
      default: null
    },
    subPath: {
      type: String,
      default: 'temp'
    },
    btnLabel: {
      type: String,
      required: false,
      default: '上传'
    },
    winTitle: {
      type: String,
      default: '文件上传'
    },
    btnIcon: {
      type: String,
      default: 'el-icon-upload'
    },
    fileMaxSize: {
      type: Number,
      default: 100
    },
    fileTemplate: {
      type: [String, Array],
      default: null
    },
    action: {
      type: String,
      default: window.context.portal + '/manager/common/upload/excel'
    }
  },
  data() {
    return {
      loading: false,
      vloading: false,
      winStatus: false,
      form: { id: null, code: null, name: null, remark: null, parentId: null, sort: null },
      upladUrlParam: ''
    }
  },

  computed: mapState({
    header: state => {
      return {
        Authorization: `Bearer ${state.login.currentUser.token}`
      }
    }
  }),

  mounted() {
    const param = { subpath: this.subPath }
    if (this.handleClass) {
      param.handle = this.handleClass
    }
    if (this.value && this.value instanceof Object) {
      for (const k in this.value) {
        param[k] = this.value[k]
      }
    }

    this.upladUrlParam = '&' + qs.stringify(param, { indices: false })
  },

  methods: {
    updateVal: function(val) {
      this.$emit('input', val)
    },
    cancelCU() {
      this.winStatus = false
    },
    toUpload() {
      this.form.name = ''
      this.winStatus = true
    },
    // 上传文件
    upload() {
      this.$refs.upload.submit()
    },
    handleOnChange(file, fileList) {
      if (!this.form.name || this.form.name === '') {
        this.form.name = file.name
      }
    },
    handleOnremove(file) {
      this.form.name = ''
    },
    beforeUpload(file) {
      let isLt2M = true
      // console.log(file)
      isLt2M = file.size / 1024 / 1024 < this.fileMaxSize
      if (!isLt2M) {
        this.loading = false
        this.vloading = false
        this.$message.error('上传文件大小不能超过 ' + this.fileMaxSize + 'MB!')
        return false
      }
      this.$emit('before-upload', file)
      this.vloading = true
      this.loading = true
      return isLt2M
    },
    handleSuccess(response, file, fileList) {
      // this.crud.notify('上传成功', CRUD.NOTIFICATION_TYPE.SUCCESS)
      this.$refs.upload.clearFiles()
      this.winStatus = false
      this.loading = false
      this.$emit('after-upload', response, file, fileList)
      this.updateVal('/' + this.subPath + '/' + response.type + '/' + response.realName)
      this.vloading = false
    },
    // 监听上传失败
    handleError(e, file, fileList) {
      this.loading = false
      this.vloading = false
      const msg = JSON.parse(e.message)
      this.$notify({
        title: msg.message,
        type: 'error',
        duration: 3500
      })
      this.$refs.upload.clearFiles()
      this.winStatus = false
    }
  }
}
</script>

<style scoped>

</style>
